@@ -1,3 +1,4 @@
+from PyQt5.QtCore import Qt
 from PyQt5.QtGui import QPixmap
 from PyQt5.QtWidgets import QGraphicsScene, QGraphicsView
 
@@ -5,6 +6,7 @@ from PyQt5.QtWidgets import QGraphicsScene, QGraphicsView
 class SingleImageGraphicsView(QGraphicsView):
     def __init__(self):
         super().__init__()
+        self.__aspectRatioMode = Qt.KeepAspectRatio
         self.__initVal()
 
     def __initVal(self):
@@ -23,4 +25,13 @@ class SingleImageGraphicsView(QGraphicsView):
         self._p = p
         self._scene = QGraphicsScene()
         self._item = self._scene.addPixmap(self._p)
-        self.setScene(self._scene)
\ No newline at end of file
+        self.setScene(self._scene)
+        self.fitInView(self._item, self.__aspectRatioMode)
+
+    def setAspectRatioMode(self, mode):
+        self.__aspectRatioMode = mode
+
+    def resizeEvent(self, e):
+        if self._item:
+            self.fitInView(self._item, self.__aspectRatioMode)
+        return super().resizeEvent(e)
\ No newline at end of file
